==> vue-code-generator-plugin-test-0.0.2.tgz: package/es/generator/plugins/component/vue3/methods.js <==
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _extends from "@babel/runtime/helpers/extends";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import { ChunkType } from '@alilc/lowcode-code-generator';
import _ from 'lodash';
import { VUE_CHUNK_NAME } from './const';
var pluginFactory = function pluginFactory(config) {
  var cfg = _extends({
    fileType: 'vue'
  }, config);
  var plugin = /*#__PURE__*/function () {
    var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(pre) {
      var next, ir, createMethodsContent;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) switch (_context.prev = _context.next) {
          case 0:
            next = _extends({}, pre);
            ir = next.ir;
            if (ir.methods) {
              _context.next = 4;
              break;
            }
            return _context.abrupt("return", next);
          case 4:
            createMethodsContent = function createMethodsContent() {
              var pieces = [];
              _.forIn(ir.methods, function (item, methodName) {
                if (item.type === 'JSFunction') {
                  var modifiedString = item.value.replace("function (", "function " + methodName + " (");
                  pieces.push(modifiedString);
                }
              });
              return pieces.join('\n');
            };
            next.chunks.push({
              type: ChunkType.STRING,
              fileType: cfg.fileType,
              name: VUE_CHUNK_NAME.ScriptMethods,
              content: createMethodsContent(),
              linkAfter: [VUE_CHUNK_NAME.ScriptStart, VUE_CHUNK_NAME.ScriptVueImp, VUE_CHUNK_NAME.ScriptInitState, VUE_CHUNK_NAME.ScriptLifeCycles]
            });
            return _context.abrupt("return", next);
          case 7:
          case "end":
            return _context.stop();
        }
      }, _callee);
    }));
    return function plugin(_x) {
      return _ref.apply(this, arguments);
    };
  }();
  return plugin;
};
export default pluginFactory;

==> vue-code-generator-plugin-test-0.0.3.tgz: package/es/generator/plugins/component/vue3/methods.js <==
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _extends from "@babel/runtime/helpers/extends";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import { ChunkType } from '@alilc/lowcode-code-generator';
import _ from 'lodash';
import { VUE_CHUNK_NAME } from './const';
var pluginFactory = function pluginFactory(config) {
  var cfg = _extends({
    fileType: 'vue'
  }, config);
  var plugin = /*#__PURE__*/function () {
    var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(pre) {
      var next, ir, createMethodsContent;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) switch (_context.prev = _context.next) {
          case 0:
            next = _extends({}, pre);
            ir = next.ir;
            if (ir.methods) {
              _context.next = 4;
              break;
            }
            return _context.abrupt("return", next);
          case 4:
            createMethodsContent = function createMethodsContent() {
              var pieces = [];
              _.forIn(ir.methods, function (item, methodName) {
                if (item.type === 'JSFunction') {
                  var modifiedString = item.value.replace('function (', "function " + methodName + " (");
                  pieces.push(modifiedString);
                }
              });
              return pieces.join('\n');
            };
            next.chunks.push({
              type: ChunkType.STRING,
              fileType: cfg.fileType,
              name: VUE_CHUNK_NAME.ScriptMethods,
              content: createMethodsContent(),
              linkAfter: [VUE_CHUNK_NAME.ScriptStart, VUE_CHUNK_NAME.ScriptVueImp, VUE_CHUNK_NAME.ScriptInitState, VUE_CHUNK_NAME.ScriptMockApi, VUE_CHUNK_NAME.ScriptLifeCycles]
            });
            return _context.abrupt("return", next);
          case 7:
          case "end":
            return _context.stop();
        }
      }, _callee);
    }));
    return function plugin(_x) {
      return _ref.apply(this, arguments);
    };
  }();
  return plugin;
};
export default pluginFactory;
